<?php

namespace App\Controller;

use App\Entity\Contact;
use App\Form\Type\ContactType;
use App\Entity\Calculator;
use App\Form\Type\CalculatorType;
use App\Model\ApiService;
use App\Model\MailService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

class HomepageController extends AbstractController
{

    public function __construct(
        private MailService $mailService,
        private ApiService $apiService,
    )
    {
    }

    #[Route('/', name: 'homepage')]
    public function index(): Response
    {
        $calculator = new Calculator();
        $calculatorForm = $this->createForm(CalculatorType::class, $calculator);

        $contact = new Contact();
        $contactForm = $this->createForm(ContactType::class, $contact);

        return $this->render('homepage/index.html.twig', [
            'calculator' => $calculatorForm,
            'contact' => $contactForm
        ]);
    }

    #[Route('/ajax-contact', name: 'ajax_contact', methods: ['POST'])]
    public function ajaxContact(Request $request): Response
    {
        $contact = new Contact();
        $form = $this->createForm(ContactType::class, $contact);

        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {

            $this->mailService->sendMail($contact);

            return new Response("Formulář jsme úspěšně odeslali. Brzy se Vám ozveme zpět.");
        }

        return new Response("Ve formuláři se nachází chyby.");
    }

    #[Route('/ajax-calculator', name: 'ajax_calculator', methods: ['POST'])]
    public function ajaxCalculator(Request $request): Response
    {
        $calculator = new Calculator();
        $form = $this->createForm(CalculatorType::class, $calculator);

        $form->handleRequest($request);
        if ($form->isSubmitted() && $form->isValid()) {
            $result = $this->apiService->setApiData($calculator);

            return new Response($result);
        }

        return new Response("Ve formuláři se nachází chyby.");
    }
}
