<?php

namespace App\Model;

use App\Entity\Calculator;
use DateTime;
use Symfony\Contracts\HttpClient\HttpClientInterface;

class ApiService
{
    public function __construct(
        private string $valuoApiKey,
        private HttpClientInterface $client,
    )
    {
    }

    private function getValuoData(array $data): array
    {
        $response = $this->client->request(
            'POST',
            'https://api.valuo.cz/v1/calculation',
            [
                'auth_bearer' => $this->valuoApiKey,
                'json' => $data,
            ]
        );

        return $response->toArray();
    }

    public function setApiData(Calculator $calculator): string
    {
        $apiData = [];
        $apiData['property_type'] = $calculator->getPropertyType();
        $apiData['kind'] = $calculator->getSellRent();
        $apiData['place'] = $calculator->getCoordinates();
        $apiData['floor_area'] = $calculator->getFloorArea();
        $apiData['lot_area'] = $calculator->getLandArea();
        $apiData['rating'] = $calculator->getPropertyCondition();
        $apiData['parking_spaces'] = $calculator->getParkingSpaces();
        $apiData['other_area'] = $calculator->getOtherDimensions();

        $date = new DateTime();
        $date = $date->format('d.m.Y');
        $apiData['as_of'] = $date;

        $response = $this->getValuoData($apiData);

        if ($response["success"] === true){
            return $response["result"]["avg_price"];
        }

        return "Nebyla vyhodnocena žádná cena.";
    }
}
